import { BasicEvent } from "@skeldjs/events";
import { RoomEvent } from "../RoomEvent";
import { GameData } from "../../objects";
import { Hostable } from "../../Hostable";
import { PlayerInfo, TaskState } from "../../misc";
import { GameDataEvent } from "./GameDataEvent";
/**
 * Emitted when a player's tasks are set.
 */
export declare class GameDataSetTasksEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, GameDataEvent {
    readonly room: RoomType;
    readonly gamedata: GameData<RoomType>;
    /**
     * Information about the player that had their tasks set.
     */
    readonly player: PlayerInfo<RoomType>;
    /**
     * The player's old tasks.
     */
    readonly oldTasks: TaskState[];
    /**
     * The player's new tasks that were just set.
     */
    readonly newTasks: TaskState[];
    static eventName: "gamedata.settasks";
    eventName: "gamedata.settasks";
    private _alteredTasks;
    constructor(room: RoomType, gamedata: GameData<RoomType>, 
    /**
     * Information about the player that had their tasks set.
     */
    player: PlayerInfo<RoomType>, 
    /**
     * The player's old tasks.
     */
    oldTasks: TaskState[], 
    /**
     * The player's new tasks that were just set.
     */
    newTasks: TaskState[]);
    /**
     * The alternate tasks to set the player, if changed.
     */
    get alteredTasks(): TaskState[];
    /**
     * Set the tasks to the tasks that the player had before this event.
     */
    revert(): void;
    /**
     * Change the tasks of the player that were set.
     * @param tasks Each {@link TaskType} to set the player.
     */
    setTasks(tasks: number[]): void;
}
