import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { SystemStatusEvents } from "./events";
import { MedScanJoinQueueEvent, MedScanLeaveQueueEvent } from "../events";
import { Hostable } from "../Hostable";
export interface MedScanSystemData {
    queue: PlayerData[];
}
export declare type MedScanSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    MedScanJoinQueueEvent<RoomType>,
    MedScanLeaveQueueEvent<RoomType>
]>;
/**
 * Represents a system responsible for handling the medbay scan queue.
 *
 * See {@link MedScanSystemEvents} for events to listen to.
 */
export declare class MedScanSystem<RoomType extends Hostable = Hostable> extends SystemStatus<MedScanSystemData, MedScanSystemEvents, RoomType> implements MedScanSystemData {
    /**
     * The current queue to access the medbay scan.s
     */
    queue: PlayerData<RoomType>[];
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | MedScanSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _removeFromQueue;
    private _joinQueue;
    /**
     * Add a player to the queue.
     * @param player The player to add.
     */
    addToQueue(player: PlayerData<RoomType>): Promise<void>;
    /**
     * Join the queue as the client's player.
     */
    joinQueue(): Promise<void>;
    private _leaveQueue;
    /**
     * Remove a player from the queue.
     * @param player The player to remove.
     */
    removeFromQueue(player: PlayerData<RoomType>): Promise<void>;
    /**
     * Leave the queue as the current player.
     */
    leaveQueue(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
}
